#
# spec file for package maildir-utils
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           maildir-utils
Version:        1.12.6
Release:        bp160.1.7
Summary:        Maildir indexer and searcher
License:        GPL-3.0-or-later
Group:          Productivity/Networking/Email/Utilities
URL:            https://www.djcbsoftware.nl/code/mu/
Source:         https://github.com/djcb/mu/releases/download/v%{version}/mu-%{version}.tar.xz
BuildRequires:  cld2-devel
BuildRequires:  emacs-nox >= 26.3
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gmime-3.0) >= 3.0
BuildRequires:  pkgconfig(guile-3.0)
# Optional: for outputting of messages in json
BuildRequires:  pkgconfig(json-glib-1.0)
BuildRequires:  pkgconfig(xapian-core)

%description
Set of utilities to index and search Maildirs. Upstream name is mu.

%package -n mu4e
Summary:        Emacs-based e-mail client based on the mu e-mail indexer/searcher
Group:          Productivity/Networking/Email/Clients
Requires:       %{name} = %{version}
Requires(post): %{install_info_prereq}
Requires(preun): %{install_info_prereq}
BuildArch:      noarch

%description -n mu4e
mu4e is an emacs-based e-mail client. It is based on the mu e-mail indexer/searcher.

%prep
%setup -q -n mu-%{version}

%build
%meson -Dguile=disabled
%meson_build

%install
%meson_install

%post -n mu4e
%install_info --info-dir=%{_infodir} %{_infodir}/mu4e.info.gz

%preun -n mu4e
%install_info_delete --info-dir=%{_infodir} %{_infodir}/mu4e.info.gz

%files
%doc README.org
%doc %{_datadir}/doc/mu/NEWS.org
%license COPYING
%dir %{_datadir}/doc/mu
%{_bindir}/mu
%{_mandir}/man?/*%{ext_man}

%files -n mu4e
%{_datadir}/doc/mu/mu4e-about.org
%dir %{_datadir}/emacs/site-lisp/mu4e/
%{_datadir}/emacs/site-lisp/mu4e/*.{el,elc}
%{_infodir}/mu4e.info%{?ext_info}

%changelog
* Sun Jul 28 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.6:
  * improved documentation: man-pages, mu4e reference manual, README
  * new function mu4e-save-message, to save a copy of the message at
    point
  * reduce logging a bit
  * fix mu4e-compose-pre-hook which broke with the 1.12.5 changes
  * fix bookmark support (bookmark-make-record-function)
* Fri May  3 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.5:
  * Rework message composition; split off parts into mu4e-draft.el
    This tries harder to maintain the current buffer as expected
  * This fixes e.g. emacs-report-bug handling
  * New hook mu4e-compose-post-hook for tweaking what mu4e does when
    we're done with a message (after sending, cancelling, ...).
    By default, it tries to close the frame if needed, and restore
    the window configuration. See its docstring.
  * Better handle forwarding of encoded messages
  * Don't remove non-mu4e completion in composer
  * Integrate iCalendar support with message-composition
  * Handle mu4e-sent-messages-behavior correctly when it's a function
  * Better support NetBSD
  * Support some file systems that don't put the file type in d_type
  * Improve documentation
* Tue Apr 16 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.4:
  * query when quitting emacs with unhandled marks in a headers buffer
  * fix mime-handling
  * update sent handling (simplifying it)
  * some internal improvements
  * number of small fixes / updates
  * documentation updates
  * re-enable a specific database lock; this makes indexing a bit slower,
    but hopefully avoids some db corruption.
* Tue Apr  9 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.3:
  * improve documentation / manpages
  * add --reindex option to 'mu index'
  * split off mu4e-complete-contact (for wider use)
  * work around some mail rendering issues with some emacs version
  * update some dependencies
  * fix some build warnings on older emacsen
  * fix musl build
* Mon Mar 18 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.2:
  * fix guile loading path
  * respect message-cite-reply-position
  * bring back mu4e-message-goto-(top|bottom)
  * bring back mu4e-compose-context-switch
  * bring back mu4e-compose-attach-captured-message
  * improve manpages layout
  * flag messages with "list-unsubscribe" as MailingList messages
  * fix some build warnings
* Mon Mar  4 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.1:
  * CLD2: add build option; ensure CLD2 is actually used
  * insist --maildir is absolute
  * tweak mu4e-compose; add 'display-buffer option for mu4e-compose-switch
  * fix typos, update mu4e documentation
* Mon Feb 26 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.12.0:
  * Significant speedups in both mu and mu4e
  * Reworked message composition, closer to its Gnus origins which
  adds many of its features
  * Overhauled the query parser; squashing a number of bugs/limitations,
  incl. dealing with CJK messages
  * Experimental folding of message threads
  * Better and faster indexing of HTML messages
  * Experimental search by (human) language wit CLD2
  * For details see NEWS.org file
* Fri Nov 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.8:
  * guile: fix module installation path
  * infodir: allow passing absolute path
  * mu4e-view: assign gnus-article-buffer (helps with some external
    programs)
  * mu4e: fix completion with non-quick keys (when using completion
    frameworks)
* Fri Sep  1 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.7:
  * Fix mu4e-compose-complete-addresses defcustom
  * Allow for specifying the guile dir (useful for distros)
    meson setup -Dguile-extension-dir= build
* Sun Aug  6 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.6:
  * mu4e: clarify sortable fields in UI
  * mu4e: fix mu4e-view-refresh
  * guile: use the standard guile extension directory
  * mu: expand file paths in command-line options (e.g.,
  - -maildir=~/Maildir) for shell that don't do so themselves (such as
    bash)
  * mu: set default batch-size to 50000 so we won't use too much memory
    (the old default broke systems with limited memory)
* Mon Jul 10 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.5:
  * in single-window mode, restore point after quitting headers-mode
  * check the part-type in Multipart (avoids an error in verifying
    unsigned messages with a signed attachment)
* Fri Jun 23 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.4:
  * contact/display-name: quote "names" with '@'
  * gmime-test: fix leak
  * mu4e: run mu4e-view-rendered-hook non-read-only (#2500)
  * mu4e: don't error out in mu4e-view-quit (#2487)
  * mu4e: add mu4e-fetch-field
  * message: remove control characters from subject (#2477)
  * meson.build: avoid clang build warning
* Mon Apr 17 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.3:
  * fix logger unit-test build for some environments
  * mu/mu4e: improve server error messages
  * add 'uninstall' target to makefile
  * reset mu4e--last-delta-unread (notifications)
* Sun Apr  9 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.2:
  * improve unit tests
  * fix threading issue with file-based logging
  * re-enable --after option for mu cfind
  * allow extracting message-parts from message (mu extract)
  * allow using relative message paths (view/extract/verify)
  Mu4e:
  * by default, don't reuse frame with composing in new frame
  * allow for disabling global modeline items
  * create random name for newly detached views
  * documentation update
* Sun Apr  2 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.1:
  * defcustom typing updates
  * re-enable json output for mu-find
  * restore emacs27 compatibility (buffer-local-boundp)
  * avoid tramp cornercase for mu4e version check
  * handle function-type bookmarks again
  * restore terminal colors after error
* Mon Mar 27 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.10.0:
  mu:
  * a new command-line parser, which allows (hopefully!) for a better user
    interaction; better error checking and more
  * Invalid e-mail addresses are no longer added to the contacts-cache.
  * The cfind command gained --format=json, which makes it easy to further
    process contact information, e.g. using jq. See the manpage for more details.
  * The init command learned --reinit to reinitialize the database
    with the setings of an exisitng one
  * The script command is gone, and integrated with mu directly, i.e. the
    scripts (when enabled) are directly visible in the mu output. Also see
    the Guile section.
  * The extract command gained the --uncooked option to tell it to not replace
    spaces with dashes in extracted filenames (and a few other things).
  * Revamped manpages which are now generated from org descriptions
  * Standardize on PCRE-flavored regular expressions throughout mu.
  * Experimental: as bit of a hack, html message bodies are processed as if
    they were plain text, similar how “old mu” would do it (1.6.x and earlier).
    A nicer solution would be to convert to text, but this something for the future.
  * the MSYS2 (Windows) builds is experimental now; some things may not work;
    see e.g. https://github.com/djcb/mu/issues?q=is%%3Aissue+label%%3Amsys, but
    we welcome efforts to fix those things.
  mu4e:
  * emacs 26.3 or higher is now required for mu4e
  * mu4e-view-mode-hook now fires before the message is rendered. If you have
    hook-functions that depend on the message contents, you should use the new mu4e-view-rendered-hook.
  * mu4e window management has been completely reworked and cleaned up, affecting
    the message loading as well as the window-layout. As a user-visible feature, there’s
    now the z binding (mu4e-view-detach), to ‘detach’ view and alllow for keeping multiple
    views around; see the manual entry for further details.
  * As a result of that, mu4e-split-view can no longer be a function; the new way is to
    use display-buffer-alist as explained in the manual
  * mu4e now keeps track of ‘baseline’ query results and shows the difference from that
    in the main view and modeline (you’ll might see something like 1(+1)/2 for your bookmarks
    or in the modeline; that means that there is one more unread message since baseline;
    see the manual entry for details. The idea is that you get a quick overview of where
    changes happened while you were doing something else. This is a somewhat experimental
    feature which is under active development
  * Related to that, you can now crown one of your bookmarks in mu4e-bookmarks with :favorite t,
    causing it to be highlighted in the main view and used in the mode-line. See the new modeline
    entry in the manual; this uses the new mu4e-modeline-mode minor-mode.
  * Expanding on that further, you can also get desktop notifications for new mail (on systems
    with DBus for now; see Desktop notifications in the manual.
  * If your search query matches some bookmark, the modeline now shows the bookmark’s name
    rather than the query; this can be controlled through mu4e-modeline-prefer-bookmark-name (default: t).
  * You can now tell mu4e to use emacs’ completion system rather than the mu4e built-in one;
    see the variables mu4e-read-option-use-builtin and mu4e-completing-read-function; e.g. to
    always emacs completion (which may have been enhanced by various completion frameworks), use:
    (setq mu4e-read-option-use-builtin nil mu4e-completing-read-function 'completing-read)
    when moving messages (which includes changing flags), file-flags changes are propagated to
    duplicates of the messages; that is, e.g. the Seen or Replied status is propagated to all
    duplicates (earlier, this was only done when marking a message as read). Note, Draft, Flagged
    and Trashed flags are deliberately not propagated.
  * Teach mu4e-copy-thing-at-point about shr links
  * The mu4e-headers-toggle-setting has been renamed mu4e-headers-toggle-property and has the new
    default binding P, which works in both the headers-view and message-view. The older functions
    mu4e-headers-toggle-threading, mu4e-headers-toggle-threading, mu4e-headers-toggle-full-search
    mu4e-headers-toggle-include-related, full-search~skip-duplicates have been removed (with their
    keybindings) in favor of mu4e-headers-toggle-property.
  * There’s also a new property mu4e-headers-hide-enabled, which controls wheter mu4e-headers-hide-predicate
    is applied (when non-~nil~). This can be used to temporarily turn the predicate off/on.
  * You can now jump to previous / next threads in headers-view, message view. Default binding is
    { and }, respectively.
  * When searching, the number of hidden messages is now shown in the message footer along with the
    number of Found messages
  * The eldoc support in header-mode is now optional and disabled by default; set mu4e-eldoc-support
    to non-nil to enable it.
  * In the main view, the keybindings shown are a representation of the actual keybindings, rather than
    just the defaults. This is for the benefit for people who want to use different keybindings.
  * As a side-effect of that, mu4e-main-mode and mu4e-main-mode-hook functions are now invoked before
    the rendering takes place; if you’re customizations depend on happening after rendering is completed,
    use the new mu4e-main-rendered-hook instead.
  * mu4e-cache-maildir-list has been promoted to be a defcustom, enabled by default. This caches the list
    of “other” maildirs (i.e., without a shortcut).
  * For testing, a new command mu4e-server-repl to start a mu server just as mu4e does it. Note that
    this cannot run at the same time when mu4e runs.
  * all the obsolete function and variable aliases have been moved to mu4e-obsolete.el so we can
    unclutter the non-obsolete code a bit.
  internals:
  * As usual, there have been a number of internal updates in the mu codebase:
    + reworked the internal s-expression parser
    + new command-line argument parser (based on CLI11)
    + message-move flag propagation moved from the mu4e-server to mu-store
    + more mu4e~ internals have been renamed/reworked in to mu4e--.
* Sun Jan 29 2023 Michael Vetter <mvetter@suse.com>
- Update to 1.8.14:
  * create mu cache path if needed
  * fix empty 'To:' header on reply to icalendar invitation
  * use const char* from for time_to_string (avoids crash in some configs)
  * mu4e-headers: appease byte-compiler
  * mu4e-headers: fallback to :subject for :thread-subject
  * mu-query-match-decider: add 'Related' to flags (rather than replace)
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.13:
  * Make server buffer invisible
* Tue Dec  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.12:
  * Fix mu-headers-toggle-setting user feedback
  * Improve browse-url-handlers
  * Update some tests, avoid compiler warnings
* Tue Oct 25 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.11:
  * Use fake message-ids when empty
  * Add explicit check for charconv header
  * Fix outdated doc for mime part actions
  * mu-view: be clearer when no text-body found
  * Fix mu4e-header-thread-first-child-prefix copy-pasta
  * Ensure mime-parts are utf8
* Thu Sep 15 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.10:
  * Fix build with emacs 29 snapshots
  * Use save-excursion around toggling html
  * Install guile scripts and fix bindings
* Tue Aug 16 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.9:
  * Work around some Protonmail-specific (mis)behavior with messages
    References; add some tests
  * Fix probleem with mu4e~view-message being nillified when it shouldn't.
* Mon Aug  8 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.8:
  * Update mu4e-action-add-org-contact for new contact format (#2306)
  * Ensure non-nil works (rather than only t) in mu4e-server (#2310)
  * Add some more unit tests for skipdups / related messages.
* Mon Jul 25 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.7:
  * ensure the the "current message" is cleared with clearing the
    headers-view; also update mu4e-message-at-point to be stricter
  * only show messages in mu-find that exist
  * load mu4e-view earlier
* Thu Jul 14 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.6:
  * Fix the the minimized main menu
  * Be less picky with maildirs with trailing /
  * Add mu4e-copy-thing-at-point, bind to c in view
  * Add more matching tests
* Wed Jul  6 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.5:
  * some minor build updates
  * add a lispdir option
  * the 1.8.4 release & tag got mixed up, so we're going straight to 1.8.5
* Mon Jul  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.3:
  * properly install info files
  * allow for alternative emacs binaries
  * extra tests
  * mu: propagate read marks to all with same message-id
  * small doc updates
* Mon Jul  4 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.2:
  * handle some corner-case queries with special characters
  * allow searching for email address components
  * fix find with links generations
  * update doc versioning
* Sun Jun 26 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.8.1:
  mu:
  * The server protocol (as used my mu4e) has seen a number of updates, to allow for faster rendering. As before, there’s no compatibility between minor release numbers (1.4 vs 1.6 vs 1.8) nor within development series (such as 1.7). However, within a stable release (such as all 1.6.x) the protocol won’t change (except if required to fix some severe bug; never happened in practice)
  * The processed number in the indexing statistics has been renamed into checked and describes the number of message files considered for updating, which is a bit more useful that the old value, which was more-or-less synonymous with the updated number (which are the message that got (re)parsed / (re)added to the database.  Basically, it counts all the messages for which we checked their timestamp.
  * The internals of the message handling in mu have been heavily reworked; much of this is not immediately visible but is an enabler for some new features.
  * Instead of passing --muhome, you can now also set an environment variable MUHOME.
  * The info command now includes information about the last indexing operation and the last database change that took place; note that the information may be slightly delayed due to database caching.
  * the verify command for checking signatures has been updated, and is more informative
  * a new command fields provides information about the message fields and flags for use in queries. The information is the same information that mu uses and so stays up to date.
  * a new message field changed, which refers to the time/date of the last time a message was changed (the file ctime)
  * new message flags personal to search for “personal” messages, which are defined as a message with at least one personal contact, and calendar for messages with calendar-invitations.
  * message sexps are now cached in the store, which makes delivering sexp-based search results (as used by mu4e) much faster.
  mu4e:
  * the old mu4e-view is gone; only the gnus-based one remains. This allowed for removing quite a bit of old code.
  * the mu4e headers rendering is much faster (a factor of 3+), which makes displaying big results snappier. This required some updates in the headers handling and in the server protocol. Separate from that, the cached message sexps (see the mu section) make getting the results much faster. This becomes esp. clear when there are a lot of query results.
  * “related” messages are now recognizable as such in the headers-view, with their own face, mu4e-related-face; by default with an italic slant.
  * For performance testing, you can set the variable mu4e-headers-report-render-time to t and mu4e will report the search/rendering speed of each query operation.
  * Removed header-fields :attachments, :signature, :encryption and :user-agent. They’re obsolete with the Gnus-based message viewer.
  * The various “toggles” for the headers-view (full-search, include-related, skip-duplicates, threading) were a bit hard to find and with non-obvious key-bindings. For that, there is now mu4e-headers-toggle-setting (bound to M) to handle all of that. The toggles are also reflected in the mode-line; so e.g. ‘RTU’ means we’re including [R]elated messages, and show [T]hreads, skip duplicates ([U]nique).
  * A new defcustom, mu4e-view-open-program for starting the appropriate program for a give file (e.g., xdg-open). There are some reasonable defaults for various systems. This can also be set to a function.
  * indexing happens in the background now and mu4e can interact with the server while it is ongoing; this allows for using mu4e during lengthy indexing operations.
  * mu4e-index-updated-hook now fires after indexing completed, regardless of whether anything changed (before, it fired only is something changed). In your hook-functions (or elsewhere) you can check if anything changed using the new variable mu4e-index-update-status. And note that processed has been renamed into checked, with a slightly different meaning, see the mu section.
  * message-user-organization can now be used to set the Organization: header. See its docstring for details.
  * mu4e-compose-context-switch no longer attempts to update the draft folder (which turned out to be a little fragile). However, it has been updated to automatically change the Organization: header, and attempts to update the message signature. Also, there’s a key-binding now: C-c ;
  * Changed the default for mu4e-compose-complete-only-after to 2018-01-01, to filter out contacts not seen after that date.
  * As an additional measure to limit the number of contacts that mu4e loads for auto-completions, there’s mu4e-compose-complete-max, to set a precise numerical match (before any possible filtering). Set to nil (no maximum by default).
  * Updated the “fancy” characters for some header fields. Added new ones for personal and list messages.
  * Removed make-mu4e-bookmark which was obsoleted in version 1.3.9.
  * Add command mu4e-sexp-at-point for showing/hiding the s-expression for the message-at-point. Useful for development / debugging. Bound to ~,~ in headers and view mode.
  * undo is now supported across message-saves
  * a lot of the internals have been changed:
    + mu4e is slowly moving from using the ’~'= to the more common '=--'= separator for private functions; i.e., =mu4e-foo becomes mu4e--foo.
    + mu4e-utils.el had become a bit of a dumping ground for bits of code; it’s gone now, with the functionality move to topic-specific files – mu4e-folders.el, mu4e-bookmarks.el, mu4e-update.el, and included in existing files.
    + the remaining common functionality has ended up in mu4e-helpers.el
    + mu4e-search.el takes the search-specific code from mu4e-headers.el,
  guile:
  * the current guile support has been deprecated. It may be revamped at some point, but will be different from the current one, which is to be removed after 1.8
  toys:
  * the toys (mug) has been removed, as they no longer worked with the rest of the code.
* Sun Jun  5 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.6.11:
  * mu-init: update manpage #2200.
  * indexer: don't wait when indexing does not progress #2233.
  * guile: add XAPIAN_CXXFLAGS #2236.
  * mu4e: don't loop mu4e-update-index when index is empty #2240.
* Fri Dec  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.10:
  * fix --terminate help display
  * make undo work across compose saves
  * ignore .update when store is empty
  * add xapian deps
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.9:
  * Just a version bump because 1.6.8 had a mistake in them
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.8:
  * mu-query: honor maxnum for threaded queries
  * lib/mu: fix a few leaks
  * guile: fix user script path detection
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.7:
  * Add Emacs v29 support for enabling mu4e
  * mu-find: unbreak json output
  * build: detect wordexp
  * mu4e.texi: improve regexp example
  * mu int: improve docs for regexp addresses
  * mu4e.texi: Add regexp --my-address example
* Wed Nov  3 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.6:
  * Fix mu-init manpage markup
  * Extracting attachments #2116
  * mu4e-view: remove overlays before erasing
  * mu4e-view: remove overlays when erasing
  * mu4e-server: rename from mu4e-proc
  * mu4e-utils: refactor into mu4e-helpers, separate files
  * mu4e-view: remove old view
  * vars: refactor variables
  * mu4e-search: split off search functionality in minor-mode
  * build: update coding-style settings
  * mu4e-context: make it a minor-mode
  * mu4e-context: fix some flycheck warnings
  * mu4e-helpers: split off from mu4e-utils
  * build: make meson the default build system
  * build: require c++17
* Fri Aug 27 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.5:
  * Create numbered backup of attached file when already exists (#2090)
  * Use and instead of progn and fix some long lines
  * Fix mu4e-view-save-attachments void variable
  * mu4e-headers: restore mark after update
  * view-gnus: Add S-SPC to scroll-down binding
* Mon Aug 23 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.4:
  * mu4e: Add back the `h' keybinding to toggle HTML view in a gnus article
  * mu4e: toggle-html: use if-let/seq-find
  * mu4e-view-gnus: Fix some flycheck warnings (doc)
  * Create numbered backup of attached file when already exists #2090
  * Use and instead of progn and fix some long lines
  * mu4e-compose: regenerate Date: when user removes it
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.3:
  * A few more updates -- lazy indexing and thread-subjects, org
    link config.
* Mon Aug 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.2:
  * Some more fixes for problems found in the 1.6 series.
* Sun Aug  1 2021 Miquel Sabate Sola <msabate@suse.com>
- Update to 1.6.1:
  * Fixes for some problems found by early adopters.
  NOTE: After upgrading, you need to call mu init, with your preferred
  parameters before you can use mu/mu4e. This is because the underlying
  database-schema has changed.
* Mon Jan 25 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.15:
  * Fix 'mu4e-interrupt-update-mail alias definition
  * mu-msg-sexp: Improve list-post regexp
* Mon Jan  4 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.4.14:
  * lib: fix mu-msg-json build
  * mu4e-view: Use 'mu4e not "mu4e" when extracting
  * Fix `mu help` doesn't show the `init` command
  * mu4e: avoid calendar charset error
  * Disable `mm-verify-option` let-bounded in `mu4e~view-gnus`
* Mon Aug 10 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.13:
  * Bugfix release, no changes provided
* Mon Jul 27 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.12:
  * Bugfix release, no changes provided
* Wed Jun 10 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.10:
  * mu4e-headers: require mule-util for truncate-string-ellipsis
* Mon Jun  8 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.9:
  * mu4e: avoid trouble with truncate-string-to-width
* Mon Jun  1 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.8:
  * Strip properties from mu4e-completing-read-function results
  * mu4e: remove easy-accounts / no-trash-providers for now
  * Add missing space between signature verification and signers
  * mu4e-maildir-shortcuts: update for today's functionality
  * mu4e-maildir-shortcuts: update for today's functionality
* Sun May 17 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.6:
  * mu: always sort descending within threads
  * mu-server: disable readline support for now
  * Fix make-mu4e-context-account
  * mu4e-compose: fix external use (`compose-mail')
  * mu4e: support 'no trash flag' for all mark-for-trash
* Mon May 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.5:
  * typo in mu-query manpage
  * mu4e: use :hide-unread in doc
  * mu4e: better error when mu4e-mu-binary is not set
  * mu: support --eval for server testing
  * mu: don't verify signatures when it's not needed
  * mu4e-bookmarks: improve documentation
  * Make mu4e~view-message available to mu4e-view-mode-hook
  * mu4e: change spacing in main view for info section
  * mu4e.texi: Add note about s/mime
* Mon May  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.4:
  * mu: do a full index when the database is empty
  * mu4e-proc: only rename when maildir is set
  * mu-store: enlarge buffer for strftime
  * mu4e: centralize mode-line context setting code
  * mu4e: update documentation
  * mu4e: start mu4e in compose-handler, when necessary
* Wed Apr 29 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.3:
  * mu4e-view: fix gnus-button click for emacs 26
  * mu4e: Don't use (mu4e-root-maildir) with easy-accounts
  * fix `mu4e-main-buffer-hide-personal-addresses'
  * mu4e-proc: ensure some booleans are nil
  * mu4e: ask for context in mu4e~start
* Mon Apr 20 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4.1:
  * ~/.mu -> ~/.cache/mu
  * remove mentions of --rebuild
  * properly close config group
* Sun Apr 19 2020 Alexander Graul <agraul@suse.com>
-Update to 1.4:
  mu:
  * Defaults to XDG Base Directory Specification
  * New subcommand `mu init` to initialize database -- takes
    `--my-address` and `--maildir` parameters, `mu index` does not
    accept them anymore
  * New subcommand `mu info` to display information about the database
  * Contacts are now saved in the database instead of in a separate
    file
  * `--xbatchsize` and `--autoupgrade` (for `mu index`) are removed,
    both are implicit now
  mu4e:
  * Does not use `mu4e-maildir` and `mu4e-user-mail-address-list`
    variables anymore, uses information from `mu init`
  * Performance improvements related to contacts handling
  * Added gnus' calendar-invitation handling
  * Added support for custom headers
  * Added experimental "Account Setup Handler"
  * Org-mode support is enabled by default
  * Speedbar support is disabled by default
  * Messaged-id are added to draft messages (can be found with
    `mu4e-headers-skip-duplicates` enabled)
  * Bookmarks are simple plists now (`make-mu4e-bookmark` was updated)
  * Specific bookmarks can be hidden from main menu
  * `mu4e-maildir-shortcuts` are simple plists now (old format is still
    recognized)
  * Replying to mailing lists has been improved
  * Shows unread/all counts for bookmarks in main menu (on by default)
  * `mu4e-attachment-dir` is also used for composing messages
  * `mu4e` <-> `mu` communication uses s-expressions now (includes a
    REPL for testing)
* Mon Apr  8 2019 mvetter@suse.com
- Update to 1.2:
  mu:
  * Substantial (algorithmic) speed-up of message-threading
  * The query-parser now generates better queries for wildcard
    searches, by using the Xapian machinery for that (when available)
    rather than tranforming into regexp queries
  * The perl backend is hardly used and will be removed; for now we
    just disable it in the build
  * Allow outputing messages in json format, closely following the sexp
    output. This adds an (optional) dependency on the Json-Glib library
  mu4e:
  * Bump the minimal required emacs version to 24.4. This was already
    de-facto true, now it is enforced
  * In mu4e-bookmarks, allow the `:query` element to take a function
    (or lambda) to dynamically generate the query string.
  * There is a new message-view for mu4e, based on the Gnus' article-view.
    This bring a lot of (but not all) of the very rich Gnus article-mode
    feature-set to mu4e, such as S/MIME-support, syntax-highlighting.
    Enable it with: (setq mu4e-view-use-gnus t)
  * Bug fixes
* Tue Mar  5 2019 mvetter@suse.com
- bsc#1111950: Build lib in paralell the rest on one core
* Mon Feb  5 2018 mvetter@suse.com
- Update to 1.0:
  mu:
  * New, custom query parser which replaces Xapian's 'QueryParser'
    both in mu and mu4e. Existing queries should still work, but the
    new engine handles non-alphanumeric queries much better.
  * Support regular expressions in queries
  * cfind: ensure nicks are unique
  * auxiliary programs invoked from mu/mu4e survive terminating the
    shell / emacs
  mu4e:
  * Allow for rewriting message bodies
  * Toggle-menus for header settings
  * electric-quote-(local-)mode work when composing emails
  * Respect format=flowed and delsp=yes for viewing plain-text
    messages
  * Added new mu4e-split-view mode: single-window
  * Add menu item for `untrash'.p
  * Unbreak abbrevs in mu4e-compose-mode
  * Allow forwarding messages as attachments
    (`mu4e-compose-forward-as-attachment')
  * Default to 'skip duplicates' and 'include headers' in
    headers-view, which should be good defaults for most users. Can
    be customized using `mu4e-headers-skip-duplicates' and
    `mu4e-headers-include-related', respectively.
  * Many bug fixed (see github for all the details).
  * Updated documentation
- Remove upstreamed mu4e-1.0-alpha3-gh1168.patch
* Tue Jan 23 2018 dmacvicar@suse.de
- Add patch mu4e-1.0-alpha3-gh1168.patch
  * Fix for https://github.com/djcb/mu/issues/1168
- Make automake version requirement (1.14) explicit
* Mon Dec 18 2017 mvetter@suse.com
- Update to 1.0-alpha3:
  * parser: promote single value to a range for range-fields
  * mu: support 'raw' query (internally)
  * mu: handle funny msgids
  * mu4e: improve msgid quoting
  * mu4e: fix typo in mu4e~docid-msgid-param
* Mon Nov 13 2017 mvetter@suse.com
- Update to 1.0-alpha2:
  * Ensure mu4e-view-mode-hook run after text insertion
  * mu4e: fix bug preventing mu4e-headers-change-sorting to sort by list
  * mu4e: add mu4e-query-rewrite-functio
  * proc: ensure query string is utf-8
  * documentation fixes
* Sun Oct 29 2017 mvetter@suse.com
- Update to 1.0-alpha0:
  * mu4e: add mu4e-msg-changed-hook to mu4e-index-updated-hook globally
  * mu4e: Fix outdated docstring for `mu4e-headers-actions'
  * Add some improvements in attachment actions
  * mu4e: killing instead of interrupting update process
  * Use re-search-forward to find message signatures
  * mu4e: Add possibility to forward messages as attachments
  * mu: add 'tickle' command, for renaming messages
  * mu4e: allow for message body rewriting
  * mu4e: mu4e-message: allow for bodyless messages
  * mu4e: show inline text/plain as attachment
  * mu4e: don't require user-agent string
  * mu4e: Added new mu4e-split-view mode: single-window
  * mu: include signers in signature report
  * mu4e: display signers in signature header
  * bug fixes and documentation updates
* Thu Oct 26 2017 dimstar@opensuse.org
- Change gmime-devel BuildRequires to pkgconfig((gmime-2.6): do not
  care for actual package names, but for relevant symbols. In this
  specific case, gmime-devel was upgraded to version 3.0, with a
  2.6 compatibility package being present next to it.
* Tue Apr 11 2017 jengelh@inai.de
- Fix typographical issues with dots and apostrophes.
* Fri Apr  7 2017 mvetter@suse.com
- Use proper license (GPL-3.0+)
* Thu Apr  6 2017 mvetter@suse.com
- Add package mu4e (emacs+mu based email client)
- Change in BuildRequires:
  * Add emacs-nox >= 23, then mu4e gets automatically build
  * Add makeinfo, to handle info files
* Thu Mar  2 2017 mvetter@suse.com
- Initial package of version 0.9.18 for openSUSE
